pub struct PigVariant {
pub key: Identifier,
pub asset_id: Identifier,
pub baby_asset_id: Identifier,
pub model: PigModelType,
pub spawn_conditions: &'static [SpawnConditionEntry],
}Expand description
Represents a full pig variant definition from a data pack JSON file.
Fields
key: Identifierasset_id: Identifierbaby_asset_id: Identifiermodel: PigModelTypespawn_conditions: &'static [SpawnConditionEntry]Trait Implementations
Sourceimpl Debug for PigVariant
impl Debug for PigVariant
impl Eq for PigVariant
Sourceimpl PartialEq for PigVariant
impl PartialEq for PigVariant
Sourceimpl RegistryEntry for PigVariant
impl RegistryEntry for PigVariant
Sourceimpl RegistryReferenceEntry for PigVariant
impl RegistryReferenceEntry for PigVariant
Sourceconst REGISTRY_NAME: &'static str = "pig variant"
const REGISTRY_NAME: &'static str = "pig variant"
Human-readable registry name used in codec errors.
Sourcefn reference_by_id(id: usize) -> Option<&'static Self>
fn reference_by_id(id: usize) -> Option<&'static Self>
Looks up an entry by its protocol registry ID.
Sourcefn reference_by_key(key: &Identifier) -> Option<&'static Self>
fn reference_by_key(key: &Identifier) -> Option<&'static Self>
Looks up an entry by its registry key.
Sourceimpl ToNbtTag for &PigVariant
impl ToNbtTag for &PigVariant
fn to_nbt_tag(self) -> NbtTag
fn to_optional_nbt_tag(self) -> Option<NbtTag>